@@ -78,7 +78,7 @@ impl ZestRand {
             self.hash_output = Some(self.compute_block());
         }
         // Safety: known size and type before and after conversion
-        let cast_slice: &[u8; 512] = unsafe { transmute(&self.hash_output) };
+        let cast_slice: &[u8; 512] = unsafe { transmute(&self.hash_output.unwrap()) };
         let byte_val = cast_slice[self.byte_offset & 0x1FF];
         self.byte_offset += 1;
         if self.byte_offset >= 0x200 {
